# <span style="color: #FF0000;">**TIME PRINT V1.5.1**</span>
# <span style="color: yellow;">**ENGLISH**</span><br>
<span style="color: #FF4500;">This is a python package to use write effect and more in your texts !</span><br>
# <span style="color: blue;">**FUNCTIONS**</span><br>
## <span style="color: #007FFF;">**TP(seconds,"text")**</span>
<span style="color: #E6A8D7;">You want to write "<span style="color: #87CEEB">**your_text**<span style="color: #E6A8D7;">" in <span style="color: #87CEEB">**5**<span style="color: #E6A8D7;"> seconds? just use;<br>
<span style="color: #87CEEB">**TP(5,"your_text")**<span style="color: #E6A8D7;"> !<br>
<span style="color: #0F52BA">Formats: seconds: int,"text":str<br>

## <span style="color: #007FFF;">**P("text")**</span>
<span style="color: #E6A8D7;">You don't want to wait until it writes bla bla seconds ?<br>
it just goes write effect and its fast (very fast)<br>
Example;<br>
<span style="color: #87CEEB">**P("TEXT")**<br>
<span style="color: #0F52BA">format: "text":str<br>
## <span style="color: #007FFF;">**Timetag(format:str)**</span>
<span style="color: #E6A8D7;">Its not very cool thing but i added,Don't have to much talk just look ex.<br>

<span style="color: #E6A8D7;">Example format usages;<br>

<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M")<span style="color: #E6A8D7;">" Returns --> 12:56 = <span style="color: #87CEEB;">(Hours:Minutes)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M:%S")<span style="color: #E6A8D7;">" Returns --> 12:56:24 = <span style="color: #87CEEB;">(Hours:Minutes:Seconds)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%d.%m.%y")<span style="color: #E6A8D7;">" Returns --> 10.02.2023 = <span style="color: #87CEEB;">(Day.Month.Year)<br>

<span style="color: #0F52BA">It uses strftime package from time.<br>
## <span style="color: #007FFF;">**info()**</span>
<span style="color: #E6A8D7;">just info about package.<br>
My name, My email and project github repostory



# <span style="color: yellow;">**TURKISH**</span><br>
<span style="color: #FF4500;">Bu mesajlarınızda yazı efekti ve daha fazlasını kullanabileceğiniz bir python paketidir!</span><br>

# <span style="color: blue;">**FONKSIYONLAR**</span><br>
## <span style="color: #007FFF;">**TP(seconds,"text")**</span>
<span style="color: #87CEEB">**MESAJ**<span style="color: #E6A8D7;"> Mesajınızı <span style="color: #87CEEB">**5**<span style="color: #E6A8D7;"> Saniyede yazmakmı istiyorsunuz? şunu kullanın;<br>
<span style="color: #87CEEB">**TP(5,"MESAJ")**<br>
<span style="color: #0F52BA">Formatlar: saniye: int,"metin":str<br>

## <span style="color: #007FFF;">**P("text")**</span>
<span style="color: #E6A8D7;">Bilmem kaç saniye boyunca yazmasını beklemek istemiyormusunuz?<br>
bu mesajınızı hızlı (çok hızlı) bir şekilde yazar.<br>
Kullanım:<br>
<span style="color: #87CEEB">**P("MESAJINIZ")**<br>

<span style="color: #0F52BA">Format: "metin":str<br>

## <span style="color: #007FFF;">**Timetag(format:str)**</span>
<span style="color: #E6A8D7;">Çok havalı bir şey değil ama yinede ekledim. örneğe bakın.<br>

<span style="color: #E6A8D7;">Örnek format kullanımı:<br>

<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M")<span style="color: #E6A8D7;">" 12:56 Olarak Geri Döner --> <span style="color: #87CEEB;">(Saat:Dakika)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%H:%M:%S")<span style="color: #E6A8D7;">" 12:56:24 Olarak Geri Döner --> <span style="color: #87CEEB;">(Saat:Dakika:Saniye)<br>
<span style="color: #E6A8D7;">"<span style="color: #87CEEB;">Timetag("%d.%m.%y")<span style="color: #E6A8D7;">" 10.02.2023 Olarak Geri Döner --> <span style="color: #87CEEB;">(Gün.Ay.Yıl)<br>

<span style="color: #0F52BA">Time modülünden strftime paketini kullanır.<br>
## <span style="color: #007FFF;">**info()**</span>
<span style="color: #E6A8D7;">Paket hakkında bilgi<br>
Adım, email adresim ve projenin github sayfası.